@@ -27,7 +27,7 @@ var searchData=
   ['vetoexception_2eidl_24',['VetoException.idl',['../VetoException_8idl.html',1,'']]],
   ['view_2eidl_25',['View.idl',['../View_8idl.html',1,'']]],
   ['viewdescriptor_2eidl_26',['ViewDescriptor.idl',['../ViewDescriptor_8idl.html',1,'']]],
-  ['viewsettings_2eidl_27',['viewsettings.idl',['../text_2ViewSettings_8idl.html',1,'(Global Namespace)'],['../view_2ViewSettings_8idl.html',1,'(Global Namespace)']]],
+  ['viewsettings_2eidl_27',['ViewSettings.idl',['../text_2ViewSettings_8idl.html',1,'(Global Namespace)'],['../view_2ViewSettings_8idl.html',1,'(Global Namespace)']]],
   ['viewstate_2eidl_28',['ViewState.idl',['../ViewState_8idl.html',1,'']]],
   ['visibility_2eidl_29',['Visibility.idl',['../Visibility_8idl.html',1,'']]],
   ['visualeffect_2eidl_30',['VisualEffect.idl',['../VisualEffect_8idl.html',1,'']]],
